@@ -27,9 +27,20 @@ function StartPedro(editorId) {
       if (!showing) return;
       showing.CodeMirror.getScrollerElement().style.height = winHeight() + "px";
     });
+
+	$("#theme_selector").change(function() {
+		var input = document.getElementById("theme_selector");
+		var theme = input.options[input.selectedIndex].innerHTML;
+		editor.setOption("theme", theme);
+	});
+ 
     var editor = CodeMirror.fromTextArea(document.getElementById(editorId), {
       lineNumbers: true,
       matchBrackets: true,
+	  tabSize: 4,
+        indentUnit: 4,
+        indentWithTabs: true,
+        mode: "text/x-perl",
       extraKeys: {
         "F11": function(cm) {
           setFullScreen(cm, !isFullScreen(cm));
@@ -37,6 +48,23 @@ function StartPedro(editorId) {
         "Esc": function(cm) {
           if (isFullScreen(cm)) setFullScreen(cm, false);
         }
-      }
+      },
+	onCursorActivity: function() {
+		// highlight active line
+		editor.setLineClass(hlLine, null, null);
+		hlLine = editor.setLineClass(editor.getCursor().line, null, "activeline");
+
+		// Highlight selection matches
+		editor.matchHighlight("CodeMirror-matchhighlight");
+	  },
+	 onGutterClick: function(cm, n) {
+    var info = cm.lineInfo(n);
+    if (info.markerText)
+      cm.clearMarker(n);
+    else
+      cm.setMarker(n, "<span style=\"color: #900\">*</span> %N%");
+  }
 	});
+
+	var hlLine = editor.setLineClass(0, "activeline");
 }
